@@ -309,7 +309,7 @@ impl NetworkAddressTranslator {
                     let dst_port = from.destination_addr().port();
                     to.set_destination_addr(&format!("{}:{}", dst_ip, dst_port))?;
                 } else {
-                    return Err(Error::ErrOthers(format!(
+                    return Err(Error::new(format!(
                         "drop {} as {:?}",
                         from,
                         Error::ErrNoAssociatedLocalAddress
@@ -333,7 +333,7 @@ impl NetworkAddressTranslator {
                     {
                         let filters = m.filters.lock().await;
                         if !filters.contains(&filter_key) {
-                            return Err(Error::ErrOthers(format!(
+                            return Err(Error::new(format!(
                                 "drop {} as the remote {} {:?}",
                                 from,
                                 filter_key,
@@ -353,7 +353,7 @@ impl NetworkAddressTranslator {
 
                     to.set_destination_addr(&m.local)?;
                 } else {
-                    return Err(Error::ErrOthers(format!(
+                    return Err(Error::new(format!(
                         "drop {} as {:?}",
                         from,
                         Error::ErrNoNatBindingFound
